@@ -1,5 +1,5 @@
-package # Hide from the indexer.
-    MooseX::SingleArg::Meta::Role;
+package MooseX::SingleArg::Meta::Role;
+$MooseX::SingleArg::Meta::Role::VERSION = '0.08';
 use Moose::Role;
 
 has single_arg => (
