@@ -1,5 +1,5 @@
-package # Hide from the indexer.
-    MooseX::SingleArg::Meta::ToRole;
+package MooseX::SingleArg::Meta::ToRole;
+$MooseX::SingleArg::Meta::ToRole::VERSION = '0.08';
 use Moose::Role;
 
 around apply => sub{
